@@ -20,7 +20,6 @@ import argparse
 import collections
 import copy
 import os
-import warnings
 
 from oslo_utils import strutils
 import six
@@ -101,14 +100,6 @@ def _translate_attachments(info):
                 'Use the show command to see which fields are available. '
                 'Unavailable/non-existent fields will be ignored. '
                 'Default=None.')
-@utils.arg('--sort_key',
-           metavar='<sort_key>',
-           default=None,
-           help=argparse.SUPPRESS)
-@utils.arg('--sort_dir',
-           metavar='<sort_dir>',
-           default=None,
-           help=argparse.SUPPRESS)
 @utils.arg('--sort',
            metavar='<key>[:<direction>]',
            default=None,
@@ -148,16 +139,8 @@ def do_list(cs, args):
         for field_title in args.fields.split(','):
             field_titles.append(field_title)
 
-    # --sort_key and --sort_dir deprecated in kilo and is not supported
-    # with --sort
-    if args.sort and (args.sort_key or args.sort_dir):
-        raise exceptions.CommandError(
-            'The --sort_key and --sort_dir arguments are deprecated and are '
-            'not supported with --sort.')
-
     volumes = cs.volumes.list(search_opts=search_opts, marker=args.marker,
-                              limit=args.limit, sort_key=args.sort_key,
-                              sort_dir=args.sort_dir, sort=args.sort)
+                              limit=args.limit, sort=args.sort)
     shell_utils.translate_volume_keys(volumes)
 
     # Create a list of servers to which the volume is attached
@@ -179,7 +162,7 @@ def do_list(cs, args):
         if search_opts['all_tenants']:
             key_list.insert(1, 'Tenant ID')
 
-    if args.sort_key or args.sort_dir or args.sort:
+    if args.sort:
         sortby_index = None
     else:
         sortby_index = 0
@@ -293,12 +276,6 @@ class CheckSizeArgForCreate(argparse.Action):
            help='Scheduler hint, similar to nova. Repeat option to set '
                 'multiple hints. Values with the same key will be stored '
                 'as a list.')
-@utils.arg('--allow-multiattach',
-           dest='multiattach',
-           action="store_true",
-           help=('Allow volume to be attached more than once. (DEPRECATED)'
-                 ' Default=False'),
-           default=False)
 def do_create(cs, args):
     """Creates a volume."""
     # NOTE(thingee): Backwards-compatibility with v1 args
@@ -340,8 +317,7 @@ def do_create(cs, args):
                                availability_zone=args.availability_zone,
                                imageRef=image_ref,
                                metadata=volume_metadata,
-                               scheduler_hints=hints,
-                               multiattach=args.multiattach)
+                               scheduler_hints=hints)
 
     info = dict()
     volume = cs.volumes.get(volume.id)
@@ -923,24 +899,6 @@ def do_type_access_remove(cs, args):
         vtype, args.project_id)
 
 
-def do_endpoints(cs, args):
-    """Discovers endpoints registered by authentication service."""
-    warnings.warn(
-        "``cinder endpoints`` is deprecated, use ``openstack catalog list`` "
-        "instead. The ``cinder endpoints`` command may be removed in the P "
-        "release or next major release of cinderclient (v2.0.0 or greater).")
-    catalog = cs.client.service_catalog.catalog
-    for e in catalog:
-        utils.print_dict(e['endpoints'][0], e['name'])
-
-
-def do_credentials(cs, args):
-    """Shows user credentials returned from auth."""
-    warnings.warn(
-        "``cinder credentials`` is deprecated, use ``openstack token issue`` "
-        "indead.")
-
-
 @utils.arg('tenant',
            metavar='<tenant_id>',
            help='ID of tenant for which to list quotas.')
@@ -2061,25 +2019,6 @@ def do_unmanage(cs, args):
     cs.volumes.unmanage(volume.id)
 
 
-@utils.arg('volume', metavar='<volume>',
-           help='Name or ID of the volume to promote. '
-                'The volume should have the replica volume created with '
-                'source-replica argument.')
-def do_replication_promote(cs, args):
-    """Promote a secondary volume to primary for a relationship."""
-    volume = utils.find_volume(cs, args.volume)
-    cs.volumes.promote(volume.id)
-
-
-@utils.arg('volume', metavar='<volume>',
-           help='Name or ID of the volume to reenable replication. '
-                'The replication-status of the volume should be inactive.')
-def do_replication_reenable(cs, args):
-    """Sync the secondary volume with primary for a relationship."""
-    volume = utils.find_volume(cs, args.volume)
-    cs.volumes.reenable(volume.id)
-
-
 @utils.arg('--all-tenants',
            dest='all_tenants',
            metavar='<0|1>',
